@@ -616,7 +616,7 @@ func (r *ReconcileVirtualMachineImport) importDisks(provider provider.Provider,
 		if err != nil && k8serrors.IsNotFound(err) {
 			// We have to validate the disk status, so we are sure, the disk wasn't manipulated,
 			// before we execute the import:
-			valid, err := provider.ValidateDiskStatus(dv)
+			valid, err := provider.ValidateDiskStatus(dv.Name)
 			if err != nil {
 				return false, err
 			}
@@ -1047,7 +1047,11 @@ func shouldReconcile(instance *v2vv1.VirtualMachineImport) bool {
 }
 
 func shouldStartVM(instance *v2vv1.VirtualMachineImport) bool {
-	return (instance.Spec.StartVM != nil && *instance.Spec.StartVM) || (instance.Spec.StartVM == nil && instance.Spec.Warm && instance.Annotations[sourceVMInitialState] == string(provider.VMStatusUp))
+	return conditions.HasSucceededConditionOfReason(instance.Status.Conditions, v2vv1.VirtualMachineReady) &&
+		((instance.Spec.StartVM != nil && *instance.Spec.StartVM) ||
+			(instance.Spec.StartVM == nil &&
+				instance.Spec.Warm &&
+				instance.Annotations[sourceVMInitialState] == string(provider.VMStatusUp)))
 }
 
 func shouldConvertGuest(provider provider.Provider, instance *v2vv1.VirtualMachineImport) bool {
