@@ -2,7 +2,6 @@ package mapper
 
 import (
 	"fmt"
-	"math"
 	"regexp"
 	"sort"
 	"strconv"
@@ -316,10 +315,8 @@ func (r *VmwareMapper) MapDataVolumes(_ *string, filesystemOverhead cdiv1.Filesy
 		storageClass := r.getStorageClassForDisk(mapping)
 
 		overhead := utils.GetOverheadForStorageClass(filesystemOverhead, storageClass)
-
-		blockSize := int64(1048576)
-		capacityWithAlignment := utils.RoundUp(disk.Capacity, blockSize)
-		capacityWithOverhead := int64(math.Ceil(float64(capacityWithAlignment) / (1 - overhead)))
+		blockSize := int64(512)
+		capacityWithOverhead := utils.RoundUp(int64(float64(disk.Capacity)/(1-overhead)), blockSize)
 		capacityAsQuantity, err := bytesToQuantity(capacityWithOverhead)
 		if err != nil {
 			return nil, err
